<?php
require_once get_template_directory() . '/framework/import.php';
require_once dirname( __FILE__ ) . '/framework/meta-box.php';
require_once dirname( __FILE__ ) . '/framework/BFI_Thumb.php';
require_once dirname( __FILE__ ) . '/framework/wp_bootstrap_navwalker.php';
if(function_exists('vc_add_param')){
require_once dirname( __FILE__ ) . '/vc_functions.php';
}

if ( ! isset( $content_width ) )
	$content_width = 604;

function housebuild_setup() {
	/*
	 * Makes housebuild available for translation.
	 *
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on housebuild, use a find and
	 * replace to change 'housebuild' to the name of your theme in all
	 * template files.
	 */
	load_theme_textdomain( 'housebuild', get_template_directory() . '/languages' );

	
	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header');
	add_theme_support( 'custom-background');
	/*
	 * Switches default core markup for search form, comment form,
	 * and comments to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	/*
	 * This theme supports all available post formats by default.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	 add_theme_support( 'post-formats', array(
		 'video'
	) );
	 
	add_theme_support( 'woocommerce' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', esc_html__( 'Navigation Menu', 'housebuild' ) );

	/*
	 * This theme uses a custom image size for featured images, displayed on
	 * "standard" posts and pages.
	 */
	add_theme_support( 'post-thumbnails' );
	
	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );
}
add_action( 'after_setup_theme', 'housebuild_setup' );

function housebuild_scripts_styles() {
	/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	// Adds Masonry to handle vertical alignment of footer widgets.
	if ( is_active_sidebar( 'sidebar-1' ) )
		wp_enqueue_script( 'jquery-masonry' );
	wp_enqueue_script("jquery");
	
	//Fonts
	$protocol = is_ssl() ? 'https' : 'http';
	wp_enqueue_style( 'google-Montserrat', "$protocol://fonts.googleapis.com/css?family=Montserrat:400,700" );
	wp_enqueue_style( 'google-lato', "$protocol://fonts.googleapis.com/css?family=Lato:300,400,700,900" );
	// Loads JavaScript file with functionality specific to Twenty Thirteen.
	wp_enqueue_script("bootstrap", get_template_directory_uri()."/js/bootstrap.min.js",array(),false,true);
	wp_enqueue_script("theme-imagesloaded", get_template_directory_uri()."/js/jquery.imagesloaded.min.js",array(),false,true);
	wp_enqueue_script("theme-retina", get_template_directory_uri()."/js/retina-1.1.0.min.js",array(),false,true);
	wp_enqueue_script("theme-plugins-scroll", get_template_directory_uri()."/js/plugins-scroll.js",array(),false,true);
	wp_enqueue_script("theme-isotope", get_template_directory_uri()."/js/jquery.isotope.min.js",array(),false,true);
	wp_enqueue_script("theme-flexslider", get_template_directory_uri()."/js/jquery.flexslider.js",array(),false,true);
	wp_enqueue_script("theme-bxslider", get_template_directory_uri()."/js/jquery.bxslider.min.js",array(),false,true);
	wp_enqueue_script("theme-jflickrfeed", get_template_directory_uri()."/js/jflickrfeed.min.js",array(),false,true);
	wp_enqueue_script("theme-script", get_template_directory_uri()."/js/script.js",array(),false,true);

	// Add Source Sans Pro and Bitter fonts, used in the main stylesheet.
	wp_enqueue_style( 'font-awesome-theme', get_template_directory_uri().'/css/font-awesome.min.css');
	wp_enqueue_style( 'bootstrap-theme', get_template_directory_uri().'/css/bootstrap.min.css');
	wp_enqueue_style( 'bxslider-theme', get_template_directory_uri().'/css/jquery.bxslider.css');
	wp_enqueue_style( 'flexslider-theme', get_template_directory_uri().'/css/flexslider.css');
	wp_enqueue_style( 'animate-theme', get_template_directory_uri().'/css/animate.css');
	wp_enqueue_style( 'settings-theme', get_template_directory_uri().'/css/settings.css');
	wp_enqueue_style( 'housebuild-theme', get_template_directory_uri().'/css/housebuild_style.css');
	
	// Loads our main stylesheet.
	wp_enqueue_style( 'housebuild-style', get_stylesheet_uri(), array(), '2014-01-09' );
	if(get_theme_mod('rtl')=='yes'){
	
	wp_enqueue_style( 'housebuild-rlt', get_template_directory_uri().'/rtl.css');
	}
	wp_enqueue_style( 'color', get_template_directory_uri().'/css/color.php');
	

}
add_action( 'wp_enqueue_scripts', 'housebuild_scripts_styles' );


function housebuild_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Main Widget Area', 'housebuild' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Appears in main sidebar of the site.', 'housebuild' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Leftbar', 'housebuild' ),
		'id'            => 'leftbar',
		'description'   => esc_html__( 'Appears in Page Leftbar.', 'housebuild' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Shop Sidebar', 'housebuild' ),
		'id'            => 'sidebar-shop',
		'description'   => esc_html__( 'Appears in main sidebar of Shop page.', 'housebuild' ),
		'before_widget' => '<aside id="%1$s" class="shop-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer1 Widget Area', 'housebuild' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Appears in the footer section 1 of the site.', 'housebuild' ),
		'before_widget' => '<aside id="%1$s" class="footer-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer2 Widget Area', 'housebuild' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Appears in the footer section 2 of the site.', 'housebuild' ),
		'before_widget' => '<aside id="%1$s" class="footer-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer3 Widget Area', 'housebuild' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Appears in the footer section 3 of the site.', 'housebuild' ),
		'before_widget' => '<aside id="%1$s" class="footer-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer4 Widget Area', 'housebuild' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Appears in the footer section 4 of the site.', 'housebuild' ),
		'before_widget' => '<aside id="%1$s" class="footer-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'housebuild_widgets_init' );

//pagination
function housebuild_pagination($prev = 'Prev', $next = 'Next', $pages='') {
    global $wp_query, $wp_rewrite;
    $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
    if($pages==''){
        global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
    }
    $pagination = array(
		'base' 			=> str_replace( 999999999, '%#%', get_pagenum_link( 999999999 ) ),
		'format' 		=> '',
		'current' 		=> max( 1, get_query_var('paged') ),
		'total' 		=> $pages,
		'prev_text' => $prev,
        'next_text' => $next,
		'type'			=> 'list',
		'end_size'		=> 3,
		'mid_size'		=> 3
);
    $return =  paginate_links( $pagination );
	echo str_replace( "<ul class='page-numbers'>", '<ul class="pagination-list padd-left">', $return );
}
add_filter( 'loop_shop_columns', 'housebuild_loop_shop_columns', 1, 10 );
function housebuild_loop_shop_columns( $number_columns ) {
	return 3;
}
add_action( 'init', 'housebuild_remove_wc_breadcrumbs' );
function housebuild_remove_wc_breadcrumbs() {
    remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
}
function is_realy_woocommerce_page () {
        if(  function_exists ( "is_woocommerce" ) && is_woocommerce()){
                return true;
        }
        $woocommerce_keys   =   array ( "woocommerce_shop_page_id" ,
                                        "woocommerce_terms_page_id" ,
                                        "woocommerce_cart_page_id" ,
                                        "woocommerce_checkout_page_id" ,
                                        "woocommerce_pay_page_id" ,
                                        "woocommerce_thanks_page_id" ,
                                        "woocommerce_myaccount_page_id" ,
                                        "woocommerce_edit_address_page_id" ,
                                        "woocommerce_view_order_page_id" ,
                                        "woocommerce_change_password_page_id" ,
                                        "woocommerce_logout_page_id" ,
                                        "woocommerce_lost_password_page_id" ) ;
        foreach ( $woocommerce_keys as $wc_page_id ) {
                if ( get_the_ID () == get_option ( $wc_page_id , 0 ) ) {
                        return true ;
                }
        }
        return false;
}
function housebuild_breadcrumb() {
       /* === OPTIONS === */
    $text['home']     = esc_html__('Home','housebuild'); // text for the 'Home' link
    $text['category'] = esc_html__('Archive by Category','housebuild').' "%s"'; // text for a category page
    $text['tax']       = esc_html__('Archive for','housebuild').' "%s"'; // text for a taxonomy page
    $text['search']   = esc_html__('Search Results for','housebuild').' "%s"'.esc_html__(' Query','housebuild'); // text for a search results page
    $text['tag']      = esc_html__('Posts Tagged','housebuild').' "%s"'; // text for a tag page
    $text['author']   = esc_html__('Articles Posted','housebuild').' by %s'; // text for an author page
    $text['404']      = esc_html__('Error 404','housebuild'); // text for the 404 page
    $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
    $showOnHome  = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
    $delimiter   = ''; // delimiter between crumbs
    $before      = '<li class="active">'; // tag before the current crumb
    $after       = '</li>'; // tag after the current crumb

    /* === END OF OPTIONS === */

    global $post;
    $homeLink = home_url() . '/';
    $linkBefore = '<li>';
    $linkAfter = '</li>';
    $linkAttr = ' rel="v:url" property="v:title"';
    $link = $linkBefore . '<a' . $linkAttr . ' href="%1$s">%2$s</a>' . $linkAfter;
    if (is_home() || is_front_page()) {
        if ($showOnHome == 1) echo '<div id="crumbs"><a href="' . $homeLink . '">' . $text['home'] . '</a></div>';
    } else {
        echo '<ul id="breadcrumbs" class="page-depth">' . sprintf($link, $homeLink, $text['home']) . $delimiter;
        if ( is_category() ) {
            $thisCat = get_category(get_query_var('cat'), false);
            if ($thisCat->parent != 0) {
                $cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
                $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                echo do_shortcode($cats);
            }
            echo do_shortcode($before) . sprintf($text['category'], single_cat_title('', false)) . $after;
        } elseif( is_tax() ){
            $thisCat = get_category(get_query_var('cat'), false);
            if ($thisCat->parent != 0) {
                $cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
                $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                echo do_shortcode($cats);
            }

            echo do_shortcode($before) . sprintf($text['tax'], single_cat_title('', false)) . $after;
        }elseif ( is_search() ) {
            echo do_shortcode($before) . sprintf($text['search'], get_search_query()) . $after;
        } elseif ( is_day() ) {
            echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
            echo sprintf($link, get_month_link(get_the_time('Y'),get_the_time('m')), get_the_time('F')) . $delimiter;
            echo do_shortcode($before) . get_the_time('d') . $after;
        } elseif ( is_month() ) {
            echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
            echo do_shortcode($before) . get_the_time('F') . $after;
        } elseif ( is_year() ) {
            echo do_shortcode($before) . get_the_time('Y') . $after;
        } elseif ( is_single() && !is_attachment() ) {
            if ( get_post_type() != 'post' ) {
                $post_type = get_post_type_object(get_post_type());
                $slug = $post_type->rewrite;
                printf($link, $homeLink . '/' . $slug['slug'] . '/', $post_type->labels->singular_name);
                if ($showCurrent == 1) echo do_shortcode($delimiter) . $before . get_the_title() . $after;
            } else {
                $cat = get_the_category(); $cat = $cat[0];
                $cats = get_category_parents($cat, TRUE, $delimiter);
                if ($showCurrent == 0) $cats = preg_replace("#^(.+)$delimiter$#", "$1", $cats);
                $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
                $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
                echo do_shortcode($cats);
                if ($showCurrent == 1) echo do_shortcode($before) . get_the_title() . $after;
            }
        } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
            $post_type = get_post_type_object(get_post_type());
            echo do_shortcode($before) . $post_type->labels->singular_name . $after;
        } elseif ( is_attachment() ) {
            $parent = get_post($post->post_parent);
            $cat = get_the_category($parent->ID); $cat = $cat[0];
            $cats = get_category_parents($cat, TRUE, $delimiter);
            $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
            $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
            echo do_shortcode($cats);
            printf($link, get_permalink($parent), $parent->post_title);
            if ($showCurrent == 1) echo do_shortcode($delimiter) . $before . get_the_title() . $after;
        } elseif ( is_page() && !$post->post_parent ) {
            if ($showCurrent == 1) echo do_shortcode($before) . get_the_title() . $after;
        } elseif ( is_page() && $post->post_parent ) {
            $parent_id  = $post->post_parent;
            $breadcrumbs = array();
            while ($parent_id) {
                $page = get_page($parent_id);
                $breadcrumbs[] = sprintf($link, get_permalink($page->ID), get_the_title($page->ID));
                $parent_id  = $page->post_parent;
            }
            $breadcrumbs = array_reverse($breadcrumbs);
            for ($i = 0; $i < count($breadcrumbs); $i++) {
                echo do_shortcode($breadcrumbs[$i]);
                if ($i != count($breadcrumbs)-1) echo do_shortcode($delimiter);
            }
            if ($showCurrent == 1) echo do_shortcode($delimiter) . $before . get_the_title() . $after;
        } elseif ( is_tag() ) {
            echo do_shortcode($before) . sprintf($text['tag'], single_tag_title('', false)) . $after;
        } elseif ( is_author() ) {
             global $author;
            $userdata = get_userdata($author);
            echo do_shortcode($before) . sprintf($text['author'], $userdata->display_name) . $after;
        } elseif ( is_404() ) {
            echo do_shortcode($before) . $text['404'] . $after;
        }
        if ( get_query_var('paged') ) {
            if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
            echo esc_html__('Page','housebuild') . ' ' . get_query_var('paged');
            if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
        }
        echo '</ul>';
    }
}

function housebuild_customize_register($wp_customize){
    
    
	$wp_customize->add_section( 'housebuild_logo_section' , array(
		'title'      => esc_html__('Theme Configs','housebuild'),
		'priority'   => 30,
	) );
	
	$wp_customize->add_setting('rtl', array(
        'housebuild'           => 'no',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'housebuild_logo_section',
			array(
				'label'          => esc_html__( 'RTL Language', 'housebuild' ),
				'section'        => 'housebuild_logo_section',
				'settings'       => 'rtl',
				'type'           => 'radio',
				'choices'        => array(
					'no'   => esc_html__( 'No','housebuild' ),
					'yes'  => esc_html__( 'Yes','housebuild' )
				)
			)
		)
	);
	
	$wp_customize->add_section( 'housebuild_boxed_section' , array(
		'title'      => esc_html__('Boxed Layout','housebuild'),
		'priority'   => 30,
	) );
	$wp_customize->add_setting('boxed', array(
        'housebuild'           => 'no',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'housebuild_boxed_section',
			array(
				'label'          => esc_html__( 'Turn On Boxed layout?', 'housebuild' ),
				'section'        => 'housebuild_boxed_section',
				'settings'       => 'boxed',
				'type'           => 'radio',
				'choices'        => array(
					'no'   => esc_html__( 'No','housebuild' ),
					'yes'  => esc_html__( 'Yes','housebuild' )
				)
			)
		)
	);
	$wp_customize->add_setting('boxed_background', array(
        'housebuild'           => get_template_directory_uri().'/images/patterns/patt2.png',
 
    ));
 
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'boxed_background', array(
        'label'    => esc_html__('Boxed Background', 'housebuild'),
        'section'  => 'housebuild_boxed_section',
        'settings' => 'boxed_background',
    )));
	
	
	$wp_customize->add_setting('favicon', array(
        'housebuild'           => get_template_directory_uri().'/images/fav.png',
 
    ));
	
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'favicon', array(
        'label'    => esc_html__('Favion', 'housebuild'),
        'section'  => 'housebuild_logo_section',
        'settings' => 'favicon',
    )));
	$wp_customize->add_setting('appleicon', array(
        'housebuild'           => '',
 
    ));
	
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'appleicon', array(
        'label'    => esc_html__('Apple touch icon', 'housebuild'),
        'section'  => 'housebuild_logo_section',
        'settings' => 'appleicon',
    )));
	
	$wp_customize->add_setting('breadcrumb_bg', array(
        'housebuild'           => '',
 
    ));
	
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'breadcrumb_bg', array(
        'label'    => esc_html__('Breadcrumb background', 'housebuild'),
        'section'  => 'housebuild_logo_section',
        'settings' => 'breadcrumb_bg',
    )));
	
	$wp_customize->add_section( 'housebuild_social_section' , array(
		'title'      => esc_html__('Social Setting','housebuild'),
		'priority'   => 31,
	) );
	 $wp_customize->add_setting('phone', array(
        'housebuild'           => '1234 - 5678 - 9012',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'phone',
			array(
				'label'          => esc_html__( 'Phone', 'housebuild' ),
				'section'        => 'housebuild_social_section',
				'settings'       => 'phone',
				'type'           => 'text',
				
			)
		)
	);
	$wp_customize->add_setting('mail', array(
        'housebuild'           => 'support@housebuild.com',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'mail',
			array(
				'label'          => esc_html__( 'Mail', 'housebuild' ),
				'section'        => 'housebuild_social_section',
				'settings'       => 'mail',
				'type'           => 'text',
				
			)
		)
	);
	//Button text
	 $wp_customize->add_setting('facebook', array(
        'housebuild'           => '#',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'facebook',
			array(
				'label'          => esc_html__( 'Facebook', 'housebuild' ),
				'section'        => 'housebuild_social_section',
				'settings'       => 'facebook',
				'type'           => 'text',
				
			)
		)
	);
	//Button text
	 $wp_customize->add_setting('twitter', array(
        'housebuild'           => '#',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'twitter',
			array(
				'label'          => esc_html__( 'Twitter', 'housebuild' ),
				'section'        => 'housebuild_social_section',
				'settings'       => 'twitter',
				'type'           => 'text',
				
			)
		)
	);
	//Button text
	 $wp_customize->add_setting('linkedin', array(
        'housebuild'           => '#',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'linkedin',
			array(
				'label'          => esc_html__( 'Linkedin', 'housebuild' ),
				'section'        => 'housebuild_social_section',
				'settings'       => 'linkedin',
				'type'           => 'text',
				
			)
		)
	);
	//Button text
	 $wp_customize->add_setting('pinterest', array(
        'housebuild'           => '#',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'pinterest',
			array(
				'label'          => esc_html__( 'Pinterest', 'housebuild' ),
				'section'        => 'housebuild_social_section',
				'settings'       => 'pinterest',
				'type'           => 'text',
				
			)
		)
	);
	//Button text
	 $wp_customize->add_setting('google', array(
        'housebuild'           => '#',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'google',
			array(
				'label'          => esc_html__( 'Google Plus', 'housebuild' ),
				'section'        => 'housebuild_social_section',
				'settings'       => 'google',
				'type'           => 'text',
				
			)
		)
	);

	 //  =============================
    //  = Logo Upload              =
    //  =============================
    $wp_customize->add_setting('image_upload_logo', array(
        'housebuild'           => get_template_directory_uri().'/images/logo.png',
 
    ));
 
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'image_upload_logo', array(
        'label'    => esc_html__('Your Logo', 'housebuild'),
        'section'  => 'housebuild_logo_section',
        'settings' => 'image_upload_logo',
    )));
	
	
	//Theme Main Color:
	 $wp_customize->add_setting('main_color', array(
        'housebuild'           => '#ffba00',
        'sanitize_callback' => 'sanitize_hex_color',
 
    ));
 
    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'main_color', array(
        'label'    => esc_html__('Theme Main Color', 'housebuild'),
        'section'  => 'housebuild_logo_section',
        'settings' => 'main_color',
    )));
	//Copyright text
	 $wp_customize->add_setting('copyright_text', array(
        'housebuild'           => '&copy; Copyright 2014. "Housebuild" by Nunforest. All rights reserved.',
 
    ));
	
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'copyright_text',
			array(
				'label'          => esc_html__( 'Copyright text', 'housebuild' ),
				'section'        => 'housebuild_logo_section',
				'settings'       => 'copyright_text',
				'type'           => 'text',
				
			)
		)
	);
	
}
 
add_action('customize_register', 'housebuild_customize_register');


//Custom comment List:
function housebuild_theme_comment($comment, $args, $depth) {
	global $textdomain; 
     $GLOBALS['comment'] = $comment; ?>
	 <li <?php comment_class('clearfix'); ?> id="comment-<?php comment_ID() ?>">
		<div class="comment-box">
			<?php if($comment->user_id!='0' and get_user_meta($comment->user_id, '_cmb_avatar' ,true)!=''){ ?>
				<img src="<?php echo bfi_thumb(get_user_meta($comment->user_id, '_cmb_avatar' ,true), array('width'=>80, 'height'=> 80)); ?>" />
			<?php }else{ ?>
			<?php echo get_avatar($comment,$size='80',$default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=80' ); ?>
			<?php } ?>
			<div class="comment-content">
				<h4><?php printf(__('%s','housebuild'), get_comment_author_link()) ?> <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></h4>
				<span><?php printf(__('%1$s at %2$s','housebuild'), get_comment_date(), get_comment_time()) ?></span>
				<?php comment_text() ?>
				<?php if ($comment->comment_approved == '0') : ?>
					 <em><?php esc_html_e('Your comment is awaiting moderation.','housebuild') ?></em>
					 <br />
				 <?php endif; ?>
			</div>
		</div>
	 
<?php

}
function housebuild_excerpt($limit = 30) {
 
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}

function housebuild_thumbnail_url($size){
    global $post;
    //$url = wp_get_attachment_url( get_post_thumbnail_id(get_the_ID()),$size );
    if($size==''){
        $url = wp_get_attachment_url( get_post_thumbnail_id($post->ID) );
         return $url;
    }else{
        $url = wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), $size);
         return $url[0];
    }
   
}

if(function_exists('vc_add_param')){

	vc_add_param('vc_row',array(
				  "type" => "textfield",
				  "heading" => esc_html__('Section ID', 'housebuild'),
				  "param_name" => "el_id",
				  "value" => "",
				  "description" => esc_html__("Set ID section", 'housebuild'),   
    ));
	
	vc_add_param('vc_row',array(
			  "type" => "dropdown",
			  "heading" => esc_html__('Fullwidth', 'housebuild'),
			  "param_name" => "fullwidth",
			  "value" => array(   
								__('No', 'housebuild') => 'no',  
								__('Yes', 'housebuild') => 'yes',                                                                                
							  ),
			  "description" => esc_html__("Select Fullwidth or not", 'housebuild'),      
			) 
    );

}

/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.4.0
 * @author     Thomas Griffin <thomasgriffinmedia.com>
 * @author     Gary Jones <gamajo.com>
 * @copyright  Copyright (c) 2014, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */
/**
 * Include the TGM_Plugin_Activation class.
 */
require_once dirname( __FILE__ ) . '/framework/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'housebuild_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function housebuild_register_required_plugins() {
    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(
             // This is an example of how to include a plugin from a private repo in your theme.

		array(            
            'name'               => 'WPBakery Visual Composer', // The plugin name.
            'slug'               => 'js_composer', // The plugin slug (typically the folder name).
            'source'             => 'http://qkthemes.net/plugins/js_composer.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),
		array(            
            'name'               => 'Revolution Slider', // The plugin name.
            'slug'               => 'revslider', // The plugin slug (typically the folder name).
            'source'             => 'http://qkthemes.net/plugins/revslider.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),
		array(            
            'name'               => esc_html__('QK Register Post Type','housebuild'), // The plugin name.
            'slug'               => 'qk-post_type', // The plugin slug (typically the folder name).
            'source'             => get_stylesheet_directory_uri() . '/framework/plugins/qk-post_type.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),
		
        // This is an example of how to include a plugin from the WordPress Plugin Repository.
		array(
            'name'      => 'Contact Form 7',
            'slug'      => 'contact-form-7',
            'required'  => true,
        ),
        
		array(
            'name'      => 'Widget Importer & Exporter',
            'slug'      => 'widget-importer-exporter',
            'required'  => false,
        ),
		array(
			'name'      => 'WooCommerce',
			'slug'      => 'woocommerce',
			'required'  => false,
		),
		array(
			'name'      => 'WooCommerce New Product Badge',
			'slug'      => 'woocommerce-new-product-badge',
			'required'  => false,
		),array(
            'name'      => esc_html__( 'Redux Developer Mode Disabler', 'housebuild' ),
            'slug'      => 'redux-developer-mode-disabler',
            'required'  => false,
        ),array(
            'name'      => esc_html__( 'One Click Demo Import', 'housebuild' ),
            'slug'      => 'one-click-demo-import',
            'required'  => false,
        ),
    );

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => esc_html__( 'Install Required Plugins', 'housebuild' ),
            'menu_title'                      => esc_html__( 'Install Plugins', 'housebuild' ),
            'installing'                      => esc_html__( 'Installing Plugin: %s', 'housebuild' ), // %s = plugin name.
            'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'housebuild' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'housebuild' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'housebuild' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'housebuild' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'housebuild' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'housebuild' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'housebuild' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'housebuild' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'housebuild' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'housebuild' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'housebuild' ),
            'return'                          => esc_html__( 'Return to Required Plugins Installer', 'housebuild' ),
            'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'housebuild' ),
            'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'housebuild' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );
    tgmpa( $plugins, $config );
}
if (!(is_admin() )) {
  function defer_parsing_of_js ( $url ) {
    if ( FALSE === strpos( $url, '.js' ) ) return $url;
    if ( strpos( $url, 'jquery.js' ) ) return $url;
    return "$url' defer ";
  }
  add_filter( 'clean_url', 'defer_parsing_of_js', 11, 1 );
}
?>